==> SIMD_1.0.0.zip: SIMD/NEWS.Rd <==
\name{SIMD NEWS}
\title{SIMD NEWS}
\alias{SIMD NEWS}
\encoding{UTF-8}

\section{Version 0.99.10}{\itemize{
The latest one.
}}

\section{Changes in version 0.99.9}{\itemize{
\item
put return statement in code at the end.
\item
instead of writing at each line, you paste output
lines in a single paste call and then use a single write call.
\item
use a package BiocManager instead of biocLite in the vignettes.
\item
remove a few eval=FALSE sections in vignette to ensure vignette 
to be evaluated.
}}

\section{Changes in version 0.99.8}{\itemize{
\item
Modify vignette output to BiocStyle .
\item
Add some information in README file.
}}

\section{Changes in version 0.99.7}{\itemize{
Modify the NOTE in build procedure.
}}

\section{Changes in version 0.99.6}{\itemize{
\item 
Adjust the code format to follow the coding style.
\item
Generate NEWS file in .Rd form.
\item
Add some information in README.md, vignettes and DESCRIPTION file 
to make the package SIMD be more understandable.
}}

\section{Changes in version 0.99.5}{\itemize{
\item Modify the 'TIMEOUT' happened in R biocheck.
}}

\section{Changes in version 0.99.4}{\itemize{
\item
Modify some problems in R biocheck.
}}

\section{Changes in version 0.99.3}{\itemize{
\item
Modify some problems in R biocheck.
\item
Recompile .Rd by roxygen2 package in R.
}}

\section{Changes in version 0.99.2}{\itemize{
\item
Modify some problems in R biocheck.
\item
Change the NEWS format.
}}
\section{Changes in version 0.99.1}{\itemize{
\item
Modify the problem in R check.
\item
To get the vignettes by R Markdown instead of by Sweave.
\item
Add NEWS.md in package.
}}

==> SIMD_1.28.0.zip: SIMD/NEWS.Rd <==
\name{SIMD NEWS}
\title{SIMD NEWS}
\alias{SIMD NEWS}
\encoding{UTF-8}

\section{Version 0.99.10}{\itemize{
\item The latest one.
}}

\section{Changes in version 0.99.9}{\itemize{
\item
put return statement in code at the end.
\item
instead of writing at each line, you paste output
lines in a single paste call and then use a single write call.
\item
use a package BiocManager instead of biocLite in the vignettes.
\item
remove a few eval=FALSE sections in vignette to ensure vignette 
to be evaluated.
}}

\section{Changes in version 0.99.8}{\itemize{
\item
Modify vignette output to BiocStyle .
\item
Add some information in README file.
}}

\section{Changes in version 0.99.7}{\itemize{
\item Modify the NOTE in build procedure.
}}

\section{Changes in version 0.99.6}{\itemize{
\item 
Adjust the code format to follow the coding style.
\item
Generate NEWS file in .Rd form.
\item
Add some information in README.md, vignettes and DESCRIPTION file 
to make the package SIMD be more understandable.
}}

\section{Changes in version 0.99.5}{\itemize{
\item Modify the 'TIMEOUT' happened in R biocheck.
}}

\section{Changes in version 0.99.4}{\itemize{
\item
Modify some problems in R biocheck.
}}

\section{Changes in version 0.99.3}{\itemize{
\item
Modify some problems in R biocheck.
\item
Recompile .Rd by roxygen2 package in R.
}}

\section{Changes in version 0.99.2}{\itemize{
\item
Modify some problems in R biocheck.
\item
Change the NEWS format.
}}
\section{Changes in version 0.99.1}{\itemize{
\item
Modify the problem in R check.
\item
To get the vignettes by R Markdown instead of by Sweave.
\item
Add NEWS.md in package.
}}
